@@ -1,13 +1,14 @@
 #'
 #' @import utils
 
-utils::globalVariables(c("Age",
+utils::globalVariables(c("age",
+                         "Age",
                          "Ex",
                          "Exp",
-                         "Expectancy",
-                         "Lower CI",
+                         "expectancy",
+                         "ci.upper",
                          "Model",
-                         "Upper CI",
+                         "ci.lower",
                          "X1",
                          "X2",
                          "X3",
@@ -19,11 +20,11 @@ utils::globalVariables(c("Age",
                          "lim.inf",
                          "lim.sup",
                          "log.qx",
-                         "qi",
-                         "qs",
+                         "qx.lower",
+                         "qx.upper",
                          "qx",
-                         "qx_fitted",
+                         "qx.fitted",
                          "samples",
                          "year",
                          "yint"
-                         ))
\ No newline at end of file
+                         ))
